@@ -6,6 +6,7 @@
 
 #include "exportmailjobinterfacetestimpl.h"
 #include "archivestorage.h"
+#include "exportmailfolderattributejobtestimpl.h"
 #include "resourceconvertertest.h"
 #include "saveresourceconfigtest.h"
 #include "testbackupresourcefilejob.h"
@@ -19,9 +20,7 @@ ExportMailJobInterfaceTestImpl::ExportMailJobInterfaceTestImpl(QObject *parent,
 {
 }
 
-ExportMailJobInterfaceTestImpl::~ExportMailJobInterfaceTestImpl()
-{
-}
+ExportMailJobInterfaceTestImpl::~ExportMailJobInterfaceTestImpl() = default;
 
 void ExportMailJobInterfaceTestImpl::convertCollectionToRealPath(KConfigGroup &group, const QString &currentKey)
 {
@@ -137,8 +136,24 @@ void ExportMailJobInterfaceTestImpl::exportFilters()
     const QString filename = mPathConfig + QLatin1String("filters");
     const bool fileAdded = archive()->addLocalFile(filename, Utils::configsPath() + QStringLiteral("filters"));
     if (fileAdded) {
-        Q_EMIT info(QStringLiteral("Filters backup done."));
+        emitInfo(QStringLiteral("Filters backup done."));
     } else {
         Q_EMIT error(QStringLiteral("Filters cannot be exported."));
     }
 }
+
+void ExportMailJobInterfaceTestImpl::exportFolderAttributes()
+{
+    auto job = new ExportMailFolderAttributeJobTestImpl(this);
+    job->setArchive(archive());
+    job->setExportInterface(this);
+    connect(job, &ExportMailFolderAttributeJobTestImpl::successed, this, [this]() {
+        emitInfo(QStringLiteral("Backing up Folder Attributes done."));
+        Q_EMIT exportAttributeDone();
+    });
+    connect(job, &ExportMailFolderAttributeJobTestImpl::failed, this, [this]() {
+        Q_EMIT error(QStringLiteral("Folder Attributes cannot be exported."));
+        Q_EMIT exportAttributeDone();
+    });
+    job->start();
+}
